from setuptools import setup
import setuptools
setup(name='metalScratch',
      version='0.0.2',
      description='metalScratch ',
      url='https://github.com/yueiuieui/metal_sc_new',
      author='metal_studio',
      author_email='metal_studio@foxmail.com',
      license='MIT',
      packages=setuptools.find_packages())